@@ -10,7 +10,8 @@ class Particles():
                  mass = None,
                  hsml = None,
                  nb = 32,
-                 verbose = False):
+                 verbose = False,
+                 sort = False):
         """
         Particles class is the first class that must be instantiated 
         in order to render an image with Py-SPHViewer. 
@@ -58,17 +59,25 @@ class Particles():
         The kwargs are :class:`~matplotlib.lines.Line2D` properties:
         """
 
-        
         self._name = 'PARTICLES'
-        self.__pos  = pos
-        self.__mass = mass
-        self.__nb   = nb
+
         self.__verbose = verbose
 
+        npart = np.size(mass)
+
         if(hsml == None):
-            self.__hsml = self.__det_hsml(self.__pos,self.__nb)
+            hsml = self.__det_hsml(pos,nb)
+        
+        if(sort):
+            ksort = np.argsort(hsml)
+            self.__pos  = np.ascontiguousarray(pos[:,ksort])
+            self.__mass = np.ascontiguousarray(mass[ksort])
+            self.__hsml = np.ascontiguousarray(hsml[ksort])
         else:
-            self.__hsml = np.array(hsml)
+            self.__pos  = np.ascontiguousarray(pos)
+            self.__mass = np.ascontiguousarray(mass)
+            self.__hsml = np.ascontiguousarray(hsml)
+
 
 #Setting methods:
     def set_pos(self,pos):
